poclean — Translate Toolkit 2.2.1 documentation

# poclean

This is a rudimentary tool to produce a clean file from an unclean file (Trados/Wordfast) by stripping out the tw4win indicators.

## Usage

    poclean <input> <output>

Where:

<input> | is the text versions of the unclean RTF files
<output> | is the intended output file / directory

Options:

`--version` | show program’s version number and exit
`-h, --help` | show this help message and exit
`--manpage` | output a manpage based on the help
`--progress=PROGRESS`
| show progress as: dots, none, bar, names, verbose
`--errorlevel=ERRORLEVEL`
| show errorlevel as: none, message, exception, traceback
`-i INPUT, --input=INPUT`
| read from INPUT in pot format
`-x EXCLUDE, --exclude=EXCLUDE`
| exclude names matching EXCLUDE from input paths
`-o OUTPUT, --output=OUTPUT`
| write to OUTPUT in po, pot formats
`-S, --timestamp`
| skip conversion if the output file has newer timestamp

## Examples

To create a text version of the unclean RTF file, you need UnRTF, available here: project site or here (windows).

    unrtf translation.rtf  --text > translation.po

You might need to convert the encoding of the file, with iconv, for example:

    iconv -f latin1 -t utf-8 translation.po > new_translation.po

Now you can clean the file with poclean

    poclean new_translation.po clean_translation.po